package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.CphNewGoodClassApply;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.comprehensive.domain.Vo.CphSearch;
import com.srs.comprehensive.domain.Vo.ExcelGoodClass;

/**
 * 先进班集体Mapper接口
 *
 * @author srs
 * @date 2024-05-15
 */
public interface CphNewGoodClassApplyMapper extends BaseMapper<CphNewGoodClassApply> {

    public List<ExcelGoodClass> exportFdy(CphNewGoodClassApply param);
    public List<ExcelGoodClass> exportView(CphNewGoodClassApply param);


    public List<CphNewGoodClassApply> listFdy(CphNewGoodClassApply param);


    public List<CphNewGoodClassApply> listView(CphNewGoodClassApply param);


    public CphNewGoodClassApply getStuClass(String stuNo);




    /**
     * 查询先进班集体
     *
     * @param id 先进班集体主键
     * @return 先进班集体
     */
    public CphNewGoodClassApply selectCphNewGoodClassApplyById(Long id);

    /**
     * 查询先进班集体列表
     *
     * @param cphNewGoodClassApply 先进班集体
     * @return 先进班集体集合
     */
    List<CphNewGoodClassApply> selectCphNewGoodClassApplyList(CphNewGoodClassApply cphNewGoodClassApply);

    /**
     * 新增先进班集体
     *
     * @param cphNewGoodClassApply 先进班集体
     * @return 结果
     */
    int insertCphNewGoodClassApply(CphNewGoodClassApply cphNewGoodClassApply);

    /**
     * 修改先进班集体
     *
     * @param cphNewGoodClassApply 先进班集体
     * @return 结果
     */
    int updateCphNewGoodClassApply(CphNewGoodClassApply cphNewGoodClassApply);

    /**
     * 删除先进班集体
     *
     * @param id 先进班集体主键
     * @return 结果
     */
    int deleteCphNewGoodClassApplyById(Long id);

    /**
     * 批量删除先进班集体
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCphNewGoodClassApplyByIds(Long[] ids);
}
